==> root_v3.05.04.source.tar.gz: root/g3d/inc/LinkDef.h <==
/* @(#)root/g3d:$Name:  $:$Id: LinkDef.h,v 1.5 2002/09/14 16:20:14 brun Exp $ */

/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ global gGeometry;

#pragma link C++ class TAxis3D+;
#pragma link C++ class TBRIK+;
#pragma link C++ class TCONE+;
#pragma link C++ class TCONS+;
#pragma link C++ class TCTUB-;
#pragma link C++ class TELTU+;
#pragma link C++ class TGTRA+;
#pragma link C++ class TGeometry-;
#pragma link C++ class THelix-;
#pragma link C++ class THYPE+;
#pragma link C++ class TMaterial-;
#pragma link C++ class TMixture-;
#pragma link C++ class TNode-;
#pragma link C++ class TNodeDiv+;
#pragma link C++ class TPARA+;
#pragma link C++ class TPCON-;
#pragma link C++ class TPGON+;
#pragma link C++ class TPolyLine3D-;
#pragma link C++ class TPolyMarker3D-;
#pragma link C++ class TRotMatrix-;
#pragma link C++ class TShape-;
#pragma link C++ class TSPHE-;
#pragma link C++ class TTRAP+;
#pragma link C++ class TTRD1+;
#pragma link C++ class TTRD2+;
#pragma link C++ class TTUBE-;
#pragma link C++ class TTUBS+;
#pragma link C++ class TPadOpenGLView;
#pragma link C++ class TMarker3DBox-;
#pragma link C++ class TPoints3DABC;
#pragma link C++ class TXTRU+;
#pragma link C++ class TGLViewerImp;
#pragma link C++ class TUtil3D;

#endif

==> root_v5.02.00.source.tar.gz: root/g3d/inc/LinkDef.h <==
/* @(#)root/g3d:$Name:  $:$Id: LinkDef.h,v 1.7 2004/12/06 07:22:55 brun Exp $ */

/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifdef __CINT__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ enum EHelixRangeType;

#pragma link C++ global gGeometry;

#pragma link C++ class TAxis3D+;
#pragma link C++ class TBRIK+;
#pragma link C++ class TCONE+;
#pragma link C++ class TCONS+;
#pragma link C++ class TCTUB-;
#pragma link C++ class TELTU+;
#pragma link C++ class TGTRA+;
#pragma link C++ class TGeometry-;
#pragma link C++ class THelix-;
#pragma link C++ class THYPE+;
#pragma link C++ class TMaterial-;
#pragma link C++ class TMixture-;
#pragma link C++ class TNode-;
#pragma link C++ class TNodeDiv+;
#pragma link C++ class TPARA+;
#pragma link C++ class TPCON-;
#pragma link C++ class TPGON+;
#pragma link C++ class TPolyLine3D-;
#pragma link C++ class TPolyMarker3D-;
#pragma link C++ class TRotMatrix-;
#pragma link C++ class TShape-;
#pragma link C++ class TSPHE-;
#pragma link C++ class TTRAP+;
#pragma link C++ class TTRD1+;
#pragma link C++ class TTRD2+;
#pragma link C++ class TTUBE-;
#pragma link C++ class TTUBS+;
#pragma link C++ class TMarker3DBox-;
#pragma link C++ class TPoints3DABC;
#pragma link C++ class TXTRU+;
#pragma link C++ class TUtil3D;

#endif
